director

package
v0.0.0-...-1ee9814 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2017 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeleteFooBarGo

func DeleteFooBarGo(fbg FooBarGo)

Recommended to be removed if runtime.SetFinalizer is in use.

Types

type FooBarGo

type FooBarGo interface {
	FooBarAbstract

	IsFooBarGo()
	// contains filtered or unexported methods
}

FooBarGo is a superset of FooBarAbstract and hence FooBarGo can be used as a drop in replacement for FooBarAbstract but the reverse causes a compile time error.

func NewFooBarGo

func NewFooBarGo() FooBarGo

Jump to