Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteFooBarGo ¶
func DeleteFooBarGo(fbg FooBarGo)
Recommended to be removed if runtime.SetFinalizer is in use.
Types ¶
type FooBarGo ¶
type FooBarGo interface {
FooBarAbstract
IsFooBarGo()
// contains filtered or unexported methods
}
FooBarGo is a superset of FooBarAbstract and hence FooBarGo can be used as a drop in replacement for FooBarAbstract but the reverse causes a compile time error.
func NewFooBarGo ¶
func NewFooBarGo() FooBarGo
Click to show internal directories.
Click to hide internal directories.